export BUILD_DIST=10.3-i386
export BUILD_ROOT=$PWD/root
export BUILD_RPMS=$PWD/rpms
MIRROR=download.opensuse.org

#
# Ensure that we have a list of all openSUSE-10.3-i386 rpms:
#
create_rpmlist() {
	if [ ! -s openSUSE-10.3.mirror-listing ]; then
		wget -O- http://download.opensuse.org/pub/opensuse/distribution/10.3/repo/oss/suse/i586/ |
			tr '"' '\n' </Index\ of\ _pub_opensuse_distribution_10.3_repo_oss_suse_i586.html |
			grep '^http://.*\.rpm' >openSUSE-10.3.mirror-listing
	fi
	return 1
}

#
# Get a listing of absolutely required rpms:
#
required_rpms=`BUILD_RPMS=/dev/null build --list-state 2>&1 | sed -n 's/.*nothing provides //p'`

#
# Get any if those which are missing:
#
for package in $required_rpms
do
	ls $BUILD_RPMS | grep "^$package.rpm$" ||
		ls $BUILD_RPMS | grep "^$package-[^-]*-[^-]*.i586.rpm$" ||
		create_rpmlist ||
		wget -N -P for-build/.rpm-cache/10.3-i386 `grep "/$package-[^-]*-[^-]*.i586.rpm$" openSUSE-10.3.mirror-listing`
done
REP=$MIRROR/repositories/devel:/tools:/scm/openSUSE_Factory/i586/
rpm -q monotone || {
	ping -W 1 -c 1 $MIRROR &&
		wget -N $REP/monotone-0.32-1.3.i586.rpm
	#rpm -Uhv monotone-0.32-1.3.i586.rpm
}
rpm -q gcc33 || {
	ping -W 1 -c 1 $MIRROR &&
		wget -N $REP/{cpp,gcc}33-3.3.3-41.8.i586.rpm
	#rpm -Uhv {cpp,gcc}33-3.3.3-41.8.i586.rpm
}
INIT=
if [ -e "$BUILD_ROOT/usr/bin/gcc" ] && rpm --root "$BUILD_ROOT" -q SDL-devel; then
	INIT=--no-init
fi

# With this you can copy the .rpm-cache (already downloaded rpms) for the build script
# into the chroot directory where build will find it and use it if possible:
#if [ ! -e $BUILD_ROOT -a -d for-build ]; then
#	mkdir $BUILD_ROOT
#	cp -av for-build/.[a-z]* $BUILD_ROOT
#fi

MOKO_SOURCES=$PWD/moko-sources
#if [ ! -e $BUILD_ROOT/tmp/moko -a -d $MOKO_PREPARE ]; then
mkdir -p $BUILD_ROOT/tmp/moko

copy_prepared_sources() {
	cd    $BUILD_ROOT/tmp/moko
	cp -av $MOKO_SOURCES/{sources,build} .
	for package in bitbake open{embedded,moko}; do
		if [ ! -d $package -a -s $MOKO_SOURCES/$package.tar.bz2 ]; then
			tar xvfj $MOKO_SOURCES/$package.tar.bz2
			mkdir -p stamps
			touch stamps/$package
		else
			# package already extracted or no source
			: echo "could not find $MOKO_SOURCES/$package.tar.bz2,
We'll have to use MokoMakefile to get the $package."
		fi
	done
	set -x
	#if [ -e OE.mtn.partial ]; then
	#	rm OE.mtn.bz2
	#fi
	if [ ! -s OE.mtn ]; then
		if [ -s $MOKO_SOURCES/OE.mtn ]; then
			cp -av $MOKO_SOURCES/OE.mtn OE.mtn
		elif [ -s $MOKO_SOURCES/OE.mtn.bz2 ]; then
			bunzip -k $MOKO_SOURCES/OE.mtn.bz2
			mv $MOKO_SOURCES/OE.mtn .
		else
			wget -N -O $MOKO_SOURCES/OE.mtn.bz2 \
				downloads.openmoko.org/OE/snapshots/OE-this-is-for-mtn-0.32.mtn.bz2
			bzcat $MOKO_SOURCES/OE.mtn.bz2 >OE.mtn
		fi
		if [ -s OE.mtn ]; then
			mkdir -p stamps
			touch stamps/OE.mtn
		fi
	fi
	tar xvfj $MOKO_SOURCES/sources-svn-*.tar.bz2
	if [ -d sources-svn-*/svn/ ]; then
		mv    sources-svn-*/svn/ sources
		rmdir sources-svn-*/
	else
		mv    sources-svn-* sources/svn
	fi
	mkdir build
	chown -R 99 build stamps
	cd -
}
copy_prepared_sources

#
# You only need linux32 or something like it if your build host is running
# a platform different from Linux-i386 like Linux-x86_64, it sets the
# personality for the build script to i386, making it and it's subprocesses
# think that they are running on Linux-i386 and don't generate x86_64 assembly:
#
linux32 build --prefer-rpms=$PWD $INIT
